==> grafana-8.2.3.tar.gz: grafana-8.2.3/pkg/services/provisioning/plugins/config_reader_test.go <==
package plugins

import (
	"os"
	"testing"

	"github.com/grafana/grafana/pkg/infra/log"
	"github.com/grafana/grafana/pkg/plugins"
	"github.com/stretchr/testify/require"
)

const (
	incorrectSettings = "./testdata/test-configs/incorrect-settings"
	brokenYaml        = "./testdata/test-configs/broken-yaml"
	emptyFolder       = "./testdata/test-configs/empty_folder"
	unknownApp        = "./testdata/test-configs/unknown-app"
	correctProperties = "./testdata/test-configs/correct-properties"
)

func TestConfigReader(t *testing.T) {
	t.Run("Broken yaml should return error", func(t *testing.T) {
		reader := newConfigReader(log.New("test logger"), nil)
		_, err := reader.readConfig(brokenYaml)
		require.Error(t, err)
	})

	t.Run("Skip invalid directory", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), nil)
		cfg, err := cfgProvider.readConfig(emptyFolder)
		require.NoError(t, err)
		require.Len(t, cfg, 0)
	})

	t.Run("Unknown app plugin should return error", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), fakePluginManager{})
		_, err := cfgProvider.readConfig(unknownApp)
		require.Error(t, err)
		require.Equal(t, "app plugin not installed: \"nonexisting\"", err.Error())
	})

	t.Run("Read incorrect properties", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), nil)
		_, err := cfgProvider.readConfig(incorrectSettings)
		require.Error(t, err)
		require.Equal(t, "app item 1 in configuration doesn't contain required field type", err.Error())
	})

	t.Run("Can read correct properties", func(t *testing.T) {
		pm := fakePluginManager{
			apps: map[string]*plugins.AppPlugin{
				"test-plugin":   {},
				"test-plugin-2": {},
			},
		}

		err := os.Setenv("ENABLE_PLUGIN_VAR", "test-plugin")
		require.NoError(t, err)
		t.Cleanup(func() {
			_ = os.Unsetenv("ENABLE_PLUGIN_VAR")
		})

		cfgProvider := newConfigReader(log.New("test logger"), pm)
		cfg, err := cfgProvider.readConfig(correctProperties)
		require.NoError(t, err)
		require.Len(t, cfg, 1)

		testCases := []struct {
			ExpectedPluginID string
			ExpectedOrgID    int64
			ExpectedOrgName  string
			ExpectedEnabled  bool
		}{
			{ExpectedPluginID: "test-plugin", ExpectedOrgID: 2, ExpectedOrgName: "", ExpectedEnabled: true},
			{ExpectedPluginID: "test-plugin-2", ExpectedOrgID: 3, ExpectedOrgName: "", ExpectedEnabled: false},
			{ExpectedPluginID: "test-plugin", ExpectedOrgID: 0, ExpectedOrgName: "Org 3", ExpectedEnabled: true},
			{ExpectedPluginID: "test-plugin-2", ExpectedOrgID: 1, ExpectedOrgName: "", ExpectedEnabled: true},
		}

		for index, tc := range testCases {
			app := cfg[0].Apps[index]
			require.NotNil(t, app)
			require.Equal(t, tc.ExpectedPluginID, app.PluginID)
			require.Equal(t, tc.ExpectedOrgID, app.OrgID)
			require.Equal(t, tc.ExpectedOrgName, app.OrgName)
			require.Equal(t, tc.ExpectedEnabled, app.Enabled)
		}
	})
}

type fakePluginManager struct {
	plugins.Manager

	apps map[string]*plugins.AppPlugin
}

func (pm fakePluginManager) IsAppInstalled(id string) bool {
	_, exists := pm.apps[id]
	return exists
}

==> grafana-10.0.3.tar.gz: grafana-10.0.3/pkg/services/provisioning/plugins/config_reader_test.go <==
package plugins

import (
	"context"
	"os"
	"testing"

	"github.com/stretchr/testify/require"

	"github.com/grafana/grafana/pkg/infra/log"
	"github.com/grafana/grafana/pkg/plugins"
)

const (
	incorrectSettings = "./testdata/test-configs/incorrect-settings"
	brokenYaml        = "./testdata/test-configs/broken-yaml"
	emptyFolder       = "./testdata/test-configs/empty_folder"
	unknownApp        = "./testdata/test-configs/unknown-app"
	correctProperties = "./testdata/test-configs/correct-properties"
)

func TestConfigReader(t *testing.T) {
	t.Run("Broken yaml should return error", func(t *testing.T) {
		reader := newConfigReader(log.New("test logger"), nil)
		_, err := reader.readConfig(context.Background(), brokenYaml)
		require.Error(t, err)
	})

	t.Run("Skip invalid directory", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), nil)
		cfg, err := cfgProvider.readConfig(context.Background(), emptyFolder)
		require.NoError(t, err)
		require.Len(t, cfg, 0)
	})

	t.Run("Unknown app plugin should return error", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), plugins.FakePluginStore{})
		_, err := cfgProvider.readConfig(context.Background(), unknownApp)
		require.Error(t, err)
		require.Equal(t, "plugin not installed: \"nonexisting\"", err.Error())
	})

	t.Run("Read incorrect properties", func(t *testing.T) {
		cfgProvider := newConfigReader(log.New("test logger"), nil)
		_, err := cfgProvider.readConfig(context.Background(), incorrectSettings)
		require.Error(t, err)
		require.Equal(t, "app item 1 in configuration doesn't contain required field type", err.Error())
	})

	t.Run("Can read correct properties", func(t *testing.T) {
		pm := plugins.FakePluginStore{
			PluginList: []plugins.PluginDTO{
				{JSONData: plugins.JSONData{ID: "test-plugin"}},
				{JSONData: plugins.JSONData{ID: "test-plugin-2"}},
			},
		}

		err := os.Setenv("ENABLE_PLUGIN_VAR", "test-plugin")
		require.NoError(t, err)
		t.Cleanup(func() {
			_ = os.Unsetenv("ENABLE_PLUGIN_VAR")
		})

		cfgProvider := newConfigReader(log.New("test logger"), pm)
		cfg, err := cfgProvider.readConfig(context.Background(), correctProperties)
		require.NoError(t, err)
		require.Len(t, cfg, 1)

		testCases := []struct {
			ExpectedPluginID string
			ExpectedOrgID    int64
			ExpectedOrgName  string
			ExpectedEnabled  bool
		}{
			{ExpectedPluginID: "test-plugin", ExpectedOrgID: 2, ExpectedOrgName: "", ExpectedEnabled: true},
			{ExpectedPluginID: "test-plugin-2", ExpectedOrgID: 3, ExpectedOrgName: "", ExpectedEnabled: false},
			{ExpectedPluginID: "test-plugin", ExpectedOrgID: 0, ExpectedOrgName: "Org 3", ExpectedEnabled: true},
			{ExpectedPluginID: "test-plugin-2", ExpectedOrgID: 1, ExpectedOrgName: "", ExpectedEnabled: true},
		}

		for index, tc := range testCases {
			app := cfg[0].Apps[index]
			require.NotNil(t, app)
			require.Equal(t, tc.ExpectedPluginID, app.PluginID)
			require.Equal(t, tc.ExpectedOrgID, app.OrgID)
			require.Equal(t, tc.ExpectedOrgName, app.OrgName)
			require.Equal(t, tc.ExpectedEnabled, app.Enabled)
		}
	})
}
